import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';
import { Provider } from 'react-redux';

import Switch from './Switch';
import SwitchContainer, { changeType } from './SwitchContainer';

import checkboxChange from './redux/checkboxChange';
import checkboxState from './redux/checkboxState';

import createStore from '../../test-utils/createStore';


const block = purebem.of('test-checkbox');
// Used to click the lever. Far from ideal, but at least the tests will fail if the style is refactored.
const leverElement = block('content-lever');

const clickLever = (checkbox) => {
    const lever = TestUtils.findRenderedDOMComponentWithClass(checkbox, leverElement);
    const node = ReactDOM.findDOMNode(lever);

    TestUtils.Simulate.click(node);
};

const TestCheckbox = Switch({
    block,
    displayName: 'TestCheckbox'
});

const TestSwitchContainer = SwitchContainer({
    Component: TestCheckbox
});

describe('SwitchContainer', () => {
    const path = 'condition';
    const root = 'test';
    const actionTypePrefix = 'TEST-CHECKBOX';

    it('should dispatch change event on change', () => {
        const store = createStore({
            test: {
                condition: checkboxState()
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestSwitchContainer
                    actionTypePrefix={ actionTypePrefix }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        clickLever(provider);

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(checkboxChange({
            path,
            root,
            type: changeType(actionTypePrefix),
            value: true
        }));

    });

});
