import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';
import { Provider } from 'react-redux';

import Dropdown from './Dropdown';
import DropdownContainer, { collapseType, expandType } from './DropdownContainer';

import dropdownCollapse from './redux/dropdownCollapse';
import dropdownExpand from './redux/dropdownExpand';
import dropdownState from './redux/dropdownState';
import dropdownValueOptionState from './option-value/dropdownValueOptionState';

import createStore from '../../test-utils/createStore';


const TestDropdown = Dropdown({
    block: purebem.of('test-dropdown'),
    displayName: 'TestDropdown'
});

const TestDropdownContainer = DropdownContainer({
    Component: TestDropdown
});

describe('DropdownContainer', () => {
    const path = 'option';
    const root = 'test';
    const actionTypePrefix = 'TEST-DROPDOWN';

    it('should dispatch expand event when clicked and collapsed', () => {
        const store = createStore({
            test: {
                option: dropdownState({
                    options: [
                        dropdownValueOptionState()
                    ]
                })
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestDropdownContainer
                    actionTypePrefix={ actionTypePrefix }
                    path={ path }
                    root={ root } />
            </Provider>
        );


        const container = TestUtils.findRenderedComponentWithType(provider, TestDropdownContainer);
        const node = ReactDOM.findDOMNode(container);

        TestUtils.Simulate.click(node);

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(dropdownExpand({
            path,
            root,
            type: expandType(actionTypePrefix)
        }));
    });

    it('should dispatch expand event when clicked and collapsed', () => {
        const store = createStore({
            test: {
                option: dropdownState({
                    expanded: true,
                    options: [
                        dropdownValueOptionState()
                    ]
                })
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestDropdownContainer
                    actionTypePrefix={ actionTypePrefix }
                    path={ path }
                    root={ root } />
            </Provider>
        );


        const container = TestUtils.findRenderedComponentWithType(provider, TestDropdownContainer);
        const node = ReactDOM.findDOMNode(container);

        TestUtils.Simulate.click(node);

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(dropdownCollapse({
            path,
            root,
            type: collapseType(actionTypePrefix)
        }));
    });

});
