import React, { PropTypes } from 'react';
import { connect } from 'react-redux';
import invariant from 'invariant';

import actionName from '../../utils/actionName';
import getComponentState from '../../utils/getComponentState';

import dropdownCollapse from './redux/dropdownCollapse';
import dropdownChange from './redux/dropdownChange';
import dropdownExpand from './redux/dropdownExpand';
import dropdownHighlightedIndexChange from './redux/dropdownHighlightedIndexChange';


const changeType = actionName('CHANGE');
const collapseType = actionName('COLLAPSE');
const expandType = actionName('EXPAND');
const highlightedIndexChangeType = actionName('HIGHLIGHTED-INDEX-CHANGE');

export {
    changeType,
    collapseType,
    expandType,
    highlightedIndexChangeType
};

export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing Dropdown component.');

    const Container = React.createClass({

        displayName: `${Component.displayName}Container`,

        propTypes: {
            path: PropTypes.string.isRequired,
            root: PropTypes.string.isRequired,
            // ---
            actionTypePrefix: PropTypes.string
        },

        render() {
            return (
                <Component { ...this.props } />
            );
        }

    });

    const mapStateToProps = (state, props) => {
        const { expanded, highlightedIndex, options, value } = getComponentState(state, props);
        return {
            expanded,
            highlightedIndex,
            options,
            value
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        const { path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'DROPDOWN';

        return {
            onChange: (value) => dispatch(dropdownChange({ path, root, type: changeType(actionTypePrefix), value })),
            onCollapse: () => dispatch(dropdownCollapse({ path, root, type: collapseType(actionTypePrefix) })),
            onExpand: () => dispatch(dropdownExpand({ path, root, type: expandType(actionTypePrefix) })),
            onHighlightedIndexChange: (highlightedIndex) => dispatch(dropdownHighlightedIndexChange({ highlightedIndex, path, root, type: highlightedIndexChangeType(actionTypePrefix) }))
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(Container);

};
