import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import DropdownValueOption from './DropdownValueOption';


const TestDropdownValueOption = DropdownValueOption({
    block: purebem.of('test-dropdown'),
    displayName: 'TestDropdownValueOption'
});

describe('DropdownValueOption', () => {

    it('should change value when clicked and not selected', () => {
        const onChange = jest.fn();

        const option = TestUtils.renderIntoDocument(
            <TestDropdownValueOption
                onChange={ onChange }
                selected={ false }
                value="test" />
        );

        const node = ReactDOM.findDOMNode(option);
        TestUtils.Simulate.click(node);

        expect(onChange).toHaveBeenCalledWith('test');
    });

    it('should not change value when clicked and is selected', () => {
        const onChange = jest.fn();

        const option = TestUtils.renderIntoDocument(
            <TestDropdownValueOption
                onChange={ onChange }
                selected={ true }
                value="test" />
        );

        const node = ReactDOM.findDOMNode(option);
        TestUtils.Simulate.click(node);

        expect(onChange).not.toHaveBeenCalled();
    });

    [
        { name: 'should not change value when clicked and is not selected and disabled', data: { selected: false } },
        { name: 'should not change value when clicked and is selected and disabled', data: { selected: true } }
    ].forEach((fixture) => {
        it(fixture.name, () => {
            const onChange = jest.fn();

            const option = TestUtils.renderIntoDocument(
                <TestDropdownValueOption
                    disabled={ true }
                    onChange={ onChange }
                    selected={ fixture.data.selected }
                    value="test" />
            );

            const node = ReactDOM.findDOMNode(option);
            TestUtils.Simulate.click(node);

            expect(onChange).not.toHaveBeenCalled();
        });
    });

});
