import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import Textbox from './Textbox';


const TestTextbox = Textbox({
    block: purebem.of('test-textbox'),
    displayName: 'TestTextbox'
});

describe('Textbox', () => {

    it('accepts input for text type', () => {
        let input = { rawValue: '', value: '' };

        const textbox = TestUtils.renderIntoDocument(
            <TestTextbox
                type="text"
                onChange={ (result) => input = result }
                value={ input.value } />
        );

        const node = ReactDOM.findDOMNode(textbox);
        node.value = 'a';

        TestUtils.Simulate.change(node);

        expect(input).toEqual({ rawValue: 'a', value: 'a' });
    });

    it('accepts input for integer type', () => {
        let input = { rawValue: '', value: '' };

        const textbox = TestUtils.renderIntoDocument(
            <TestTextbox
                type="integer"
                onChange={ (result) => input = result }
                value={ input.value } />
        );

        const node = ReactDOM.findDOMNode(textbox);
        node.value = '1';

        TestUtils.Simulate.change(node);

        expect(input).toEqual({ rawValue: '1', value: 1 });
    });

    it('should ignore non-number related characters for integer type', () => {
        let input = { rawValue: '', value: '' };

        const textbox = TestUtils.renderIntoDocument(
            <TestTextbox
                type="integer"
                onChange={ (result) => input = result }
                value={ input.value } />
        );

        const node = ReactDOM.findDOMNode(textbox);
        node.value = 'a';

        TestUtils.Simulate.change(node);

        expect(input).toEqual({ rawValue: '', value: '' });
    });

    it('accepts input for float type', () => {
        let input = { rawValue: '', value: '' };

        const textbox = TestUtils.renderIntoDocument(
            <TestTextbox
                type="float"
                onChange={ (result) => input = result }
                value={ input.value } />
        );

        const node = ReactDOM.findDOMNode(textbox);
        node.value = '1';

        TestUtils.Simulate.change(node);

        expect(input).toEqual({ rawValue: '1', value: 1 });
    });

    it('should ignore non-number related characters for float type', () => {
        let input = { rawValue: '', value: '' };

        const textbox = TestUtils.renderIntoDocument(
            <TestTextbox
                type="float"
                onChange={ (result) => input = result }
                value={ input.value } />
        );

        const node = ReactDOM.findDOMNode(textbox);
        node.value = 'a';

        TestUtils.Simulate.change(node);

        expect(input).toEqual({ rawValue: '', value: '' });
    });

});
